build_tracking_calibration

Function build_tracking_calibration 

pub fn build_tracking_calibration(
    scenario: &Scenario,
) -> Result<FlydraMultiCameraSystem<f64>>
Build the calibration Braid tracks with: the perfect generation calibration of build_calibration with the scenario’s CalibrationPerturbation applied (pose / intrinsic error). With the default (identity) perturbation this is byte-identical to build_calibration; with a nonzero perturbation the tracker reconstructs with a slightly wrong calibration while the detections were generated with the perfect one, so reprojection error is realistic.